@@ -296,6 +296,7 @@ pub enum AmdGpuArchitecture {
     Gfx908,
     Gfx90a,
     Gfx942,
+    Gfx950,
     Gfx1030,
     Gfx1100,
     Gfx1101,
@@ -314,6 +315,7 @@ impl FromStr for AmdGpuArchitecture {
             "gfx908" => Ok(Self::Gfx908),
             "gfx90a" => Ok(Self::Gfx90a),
             "gfx942" => Ok(Self::Gfx942),
+            "gfx950" => Ok(Self::Gfx950),
             "gfx1030" => Ok(Self::Gfx1030),
             "gfx1100" => Ok(Self::Gfx1100),
             "gfx1101" => Ok(Self::Gfx1101),
@@ -333,6 +335,7 @@ impl std::fmt::Display for AmdGpuArchitecture {
             Self::Gfx908 => write!(f, "gfx908"),
             Self::Gfx90a => write!(f, "gfx90a"),
             Self::Gfx942 => write!(f, "gfx942"),
+            Self::Gfx950 => write!(f, "gfx950"),
             Self::Gfx1030 => write!(f, "gfx1030"),
             Self::Gfx1100 => write!(f, "gfx1100"),
             Self::Gfx1101 => write!(f, "gfx1101"),
