@@ -8,7 +8,7 @@ use std::str::FromStr;
 use anyhow::{Context, Error, Result};
 use futures::{StreamExt, join};
 use indexmap::IndexSet;
-use itertools::{Either, Itertools};
+use itertools::Itertools;
 use owo_colors::{AnsiColors, OwoColorize};
 use rustc_hash::{FxHashMap, FxHashSet};
 use tokio::sync::mpsc;
@@ -19,14 +19,14 @@ use uv_client::BaseClientBuilder;
 use uv_configuration::Concurrency;
 use uv_fs::Simplified;
 use uv_platform::{Arch, Libc};
-use uv_preview::{Preview, PreviewFeatures};
+use uv_preview::{Preview, PreviewFeature};
 use uv_python::downloads::{
     self, ArchRequest, DownloadResult, ManagedPythonDownload, ManagedPythonDownloadList,
     PythonDownloadRequest,
 };
 use uv_python::managed::{
     ManagedPythonInstallation, ManagedPythonInstallations, PythonMinorVersionLink,
-    create_link_to_executable, python_executable_dir,
+    compare_build_versions, create_link_to_executable, python_executable_dir,
 };
 use uv_python::{
     ImplementationName, Interpreter, PythonDownloads, PythonInstallationKey,
@@ -177,7 +177,7 @@ pub(crate) enum PythonUpgrade {
 }
 
 /// Download and install Python versions.
-#[allow(clippy::fn_params_excessive_bools)]
+#[expect(clippy::fn_params_excessive_bools)]
 pub(crate) async fn install(
     project_dir: &Path,
     install_dir: Option<PathBuf>,
@@ -283,7 +283,7 @@ pub(crate) async fn install(
     installer_result
 }
 
-#[allow(clippy::fn_params_excessive_bools)]
+#[expect(clippy::fn_params_excessive_bools)]
 async fn perform_install(
     project_dir: &Path,
     install_dir: Option<PathBuf>,
@@ -311,18 +311,18 @@ async fn perform_install(
     // `--default` is used. It's not clear how this overlaps with a global Python pin, but I'd be
     // surprised if `uv python find` returned the "newest" Python version rather than the one I just
     // installed with the `--default` flag.
-    if default && !preview.is_enabled(PreviewFeatures::PYTHON_INSTALL_DEFAULT) {
+    if default && !preview.is_enabled(PreviewFeature::PythonInstallDefault) {
         warn_user!(
             "The `--default` option is experimental and may change without warning. Pass `--preview-features {}` to disable this warning",
-            PreviewFeatures::PYTHON_INSTALL_DEFAULT
+            PreviewFeature::PythonInstallDefault
         );
     }
 
     if let PythonUpgrade::Enabled(source @ PythonUpgradeSource::Upgrade) = upgrade {
-        if !preview.is_enabled(PreviewFeatures::PYTHON_UPGRADE) {
+        if !preview.is_enabled(PreviewFeature::PythonUpgrade) {
             warn_user!(
                 "`{source}` is experimental and may change without warning. Pass `--preview-features {}` to disable this warning",
-                PreviewFeatures::PYTHON_UPGRADE
+                PreviewFeature::PythonUpgrade
             );
         }
     }
@@ -524,24 +524,47 @@ async fn perform_install(
         (vec![], unsatisfied)
     } else {
         // If we can find one existing installation that matches the request, it is satisfied
-        requests.iter().partition_map(|request| {
-            if let Some(installation) = existing_installations.iter().find(|installation| {
-                if matches!(upgrade, PythonUpgrade::Enabled(_)) {
-                    // If this is an upgrade, the requested version is a minor version but the
-                    // requested download is the highest patch for that minor version. We need to
-                    // install it unless an exact match is found.
-                    request.download.key() == installation.key()
+        let mut satisfied = Vec::new();
+        let mut unsatisfied = Vec::new();
+
+        for request in &requests {
+            if matches!(upgrade, PythonUpgrade::Enabled(_)) {
+                // If this is an upgrade, the requested version is a minor version but the
+                // requested download is the highest patch for that minor version. We need to
+                // install it unless an exact match is found (including build version).
+                if let Some(installation) = existing_installations
+                    .iter()
+                    .find(|inst| request.download.key() == inst.key())
+                {
+                    if matches_build(request.download.build(), installation.build()) {
+                        debug!("Found `{}` for request `{}`", installation.key(), request);
+                        satisfied.push(installation);
+                    } else {
+                        // Key matches but build version differs - track as existing for reinstall
+                        debug!(
+                            "Build version mismatch for `{}`, will upgrade",
+                            installation.key()
+                        );
+                        changelog.existing.insert(installation.key().clone());
+                        unsatisfied.push(Cow::Borrowed(request));
+                    }
                 } else {
-                    request.matches_installation(installation)
+                    debug!("No installation found for request `{}`", request);
+                    unsatisfied.push(Cow::Borrowed(request));
                 }
-            }) {
+            } else if let Some(installation) = existing_installations
+                .iter()
+                .find(|inst| request.matches_installation(inst))
+            {
                 debug!("Found `{}` for request `{}`", installation.key(), request);
-                Either::Left(installation)
+                satisfied.push(installation);
             } else {
                 debug!("No installation found for request `{}`", request);
-                Either::Right(Cow::Borrowed(request))
+                unsatisfied.push(Cow::Borrowed(request));
             }
-        })
+        }
+
+        (satisfied, unsatisfied)
     };
 
     // For all satisfied installs, bytecode compile them now before any future
@@ -953,7 +976,7 @@ async fn perform_install(
 /// Link the binaries of a managed Python installation to the bin directory.
 ///
 /// This function is fallible, but errors are pushed to `errors` instead of being thrown.
-#[allow(clippy::fn_params_excessive_bools)]
+#[expect(clippy::fn_params_excessive_bools)]
 fn create_bin_links(
     installation: &ManagedPythonInstallation,
     bin: &Path,
@@ -972,8 +995,8 @@ fn create_bin_links(
     // TODO(zanieb): We want more feedback on the `is_default_install` behavior before stabilizing
     // it. In particular, it may be confusing because it does not apply when versions are loaded
     // from a `.python-version` file.
-    let should_create_default_links = default
-        || (is_default_install && preview.is_enabled(PreviewFeatures::PYTHON_INSTALL_DEFAULT));
+    let should_create_default_links =
+        default || (is_default_install && preview.is_enabled(PreviewFeature::PythonInstallDefault));
 
     let targets = if should_create_default_links {
         vec![
@@ -1324,3 +1347,17 @@ fn find_matching_bin_link<'a>(
         unreachable!("Only Unix and Windows are supported")
     }
 }
+
+/// Check if a download's build version matches an installation's build version.
+///
+/// Returns `true` if the build versions match (no upgrade needed), `false` if an upgrade is needed.
+fn matches_build(download_build: Option<&str>, installation_build: Option<&str>) -> bool {
+    match (download_build, installation_build) {
+        // Both have build, check if they match
+        (Some(d), Some(i)) => compare_build_versions(d, i) == std::cmp::Ordering::Equal,
+        // Legacy installation without BUILD file needs upgrade
+        (Some(_), None) => false,
+        // Download doesn't have build info, assume matches
+        (None, _) => true,
+    }
+}
