@@ -5,7 +5,7 @@ use assert_fs::fixture::{FileTouch, FileWriteBin, FileWriteStr, PathChild, PathC
 use flate2::bufread::GzDecoder;
 use fs_err::File;
 use indoc::{formatdoc, indoc};
-use std::env;
+use insta::{assert_json_snapshot, assert_snapshot};
 use std::io::BufReader;
 use std::path::Path;
 use std::process::Command;
@@ -35,14 +35,14 @@ fn built_by_uv_direct_wheel() -> Result<()> {
         .build_backend()
         .arg("build-wheel")
         .arg(temp_dir.path())
-        .current_dir(built_by_uv), @r###"
+        .current_dir(built_by_uv), @"
     success: true
     exit_code: 0
     ----- stdout -----
     built_by_uv-0.1.0-py3-none-any.whl
 
     ----- stderr -----
-    "###);
+    ");
 
     context
         .pip_install()
@@ -52,7 +52,7 @@ fn built_by_uv_direct_wheel() -> Result<()> {
 
     uv_snapshot!(context.python_command()
         .arg("-c")
-        .arg(BUILT_BY_UV_TEST_SCRIPT), @r###"
+        .arg(BUILT_BY_UV_TEST_SCRIPT), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -60,17 +60,17 @@ fn built_by_uv_direct_wheel() -> Result<()> {
     Area of a circle with r=2: 12.56636
 
     ----- stderr -----
-    "###);
+    ");
 
     uv_snapshot!(Command::new("say-hi")
-        .env(EnvVars::PATH, venv_bin_path(&context.venv)), @r###"
+        .env(EnvVars::PATH, venv_bin_path(&context.venv)), @"
     success: true
     exit_code: 0
     ----- stdout -----
     Hi from a script!
 
     ----- stderr -----
-    "###);
+    ");
 
     Ok(())
 }
@@ -91,14 +91,14 @@ fn built_by_uv_direct() -> Result<()> {
         .build_backend()
         .arg("build-sdist")
         .arg(sdist_dir.path())
-        .current_dir(built_by_uv), @r###"
+        .current_dir(built_by_uv), @"
     success: true
     exit_code: 0
     ----- stdout -----
     built_by_uv-0.1.0.tar.gz
 
     ----- stderr -----
-    "###);
+    ");
 
     let sdist_tree = TempDir::new()?;
 
@@ -115,14 +115,14 @@ fn built_by_uv_direct() -> Result<()> {
         .build_backend()
         .arg("build-wheel")
         .arg(wheel_dir.path())
-        .current_dir(sdist_tree.path().join("built_by_uv-0.1.0")), @r###"
+        .current_dir(sdist_tree.path().join("built_by_uv-0.1.0")), @"
     success: true
     exit_code: 0
     ----- stdout -----
     built_by_uv-0.1.0-py3-none-any.whl
 
     ----- stderr -----
-    "###);
+    ");
 
     drop(sdist_tree);
 
@@ -136,7 +136,7 @@ fn built_by_uv_direct() -> Result<()> {
 
     uv_snapshot!(context.python_command()
         .arg("-c")
-        .arg(BUILT_BY_UV_TEST_SCRIPT), @r###"
+        .arg(BUILT_BY_UV_TEST_SCRIPT), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -144,7 +144,7 @@ fn built_by_uv_direct() -> Result<()> {
     Area of a circle with r=2: 12.56636
 
     ----- stderr -----
-    "###);
+    ");
 
     Ok(())
 }
@@ -176,14 +176,14 @@ fn built_by_uv_editable() -> Result<()> {
         .build_backend()
         .arg("build-wheel")
         .arg(wheel_dir.path())
-        .current_dir(built_by_uv), @r###"
+        .current_dir(built_by_uv), @"
     success: true
     exit_code: 0
     ----- stdout -----
     built_by_uv-0.1.0-py3-none-any.whl
 
     ----- stderr -----
-    "###);
+    ");
     context
         .pip_install()
         .arg(wheel_dir.path().join("built_by_uv-0.1.0-py3-none-any.whl"))
@@ -199,7 +199,7 @@ fn built_by_uv_editable() -> Result<()> {
         // Avoid showing absolute paths and column dependent layout
         .arg("--quiet")
         .arg("--capture=no")
-        .current_dir(built_by_uv), @r###"
+        .current_dir(built_by_uv), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -207,7 +207,7 @@ fn built_by_uv_editable() -> Result<()> {
     2 passed in [TIME]
 
     ----- stderr -----
-    "###);
+    ");
 
     Ok(())
 }
@@ -262,14 +262,14 @@ fn preserve_executable_bit() -> Result<()> {
     context.pip_install().arg(wheel).assert().success();
 
     uv_snapshot!(Command::new("greet.sh")
-        .env(EnvVars::PATH, venv_bin_path(&context.venv)), @r###"
+        .env(EnvVars::PATH, venv_bin_path(&context.venv)), @"
     success: true
     exit_code: 0
     ----- stdout -----
     Hi from the shell
 
     ----- stderr -----
-    "###);
+    ");
 
     Ok(())
 }
@@ -314,14 +314,14 @@ fn rename_module() -> Result<()> {
     uv_snapshot!(context
         .build_backend()
         .arg("build-wheel")
-        .arg(temp_dir.path()), @r###"
+        .arg(temp_dir.path()), @"
     success: true
     exit_code: 0
     ----- stdout -----
     foo-1.0.0-py3-none-any.whl
 
     ----- stderr -----
-    "###);
+    ");
 
     context
         .pip_install()
@@ -332,19 +332,19 @@ fn rename_module() -> Result<()> {
     // Importing the module with the `module-name` name succeeds.
     uv_snapshot!(context.python_command()
         .arg("-c")
-        .arg("import bar"), @r###"
+        .arg("import bar"), @"
     success: true
     exit_code: 0
     ----- stdout -----
     Hi from bar
 
     ----- stderr -----
-    "###);
+    ");
 
     // Importing the package name fails, it was overridden by `module-name`.
     uv_snapshot!(context.python_command()
         .arg("-c")
-        .arg("import foo"), @r###"
+        .arg("import foo"), @r#"
     success: false
     exit_code: 1
     ----- stdout -----
@@ -353,7 +353,7 @@ fn rename_module() -> Result<()> {
     Traceback (most recent call last):
       File "<string>", line 1, in <module>
     ModuleNotFoundError: No module named 'foo'
-    "###);
+    "#);
 
     Ok(())
 }
@@ -388,14 +388,14 @@ fn rename_module_editable_build() -> Result<()> {
     uv_snapshot!(context
         .build_backend()
         .arg("build-editable")
-        .arg(temp_dir.path()), @r###"
+        .arg(temp_dir.path()), @"
     success: true
     exit_code: 0
     ----- stdout -----
     foo-1.0.0-py3-none-any.whl
 
     ----- stderr -----
-    "###);
+    ");
 
     context
         .pip_install()
@@ -406,14 +406,14 @@ fn rename_module_editable_build() -> Result<()> {
     // Importing the module with the `module-name` name succeeds.
     uv_snapshot!(context.python_command()
         .arg("-c")
-        .arg("import bar"), @r###"
+        .arg("import bar"), @"
     success: true
     exit_code: 0
     ----- stdout -----
     Hi from bar
 
     ----- stderr -----
-    "###);
+    ");
 
     Ok(())
 }
@@ -447,7 +447,7 @@ fn build_module_name_normalization() -> Result<()> {
     uv_snapshot!(context
         .build_backend()
         .arg("build-wheel")
-        .arg(&wheel_dir), @r"
+        .arg(&wheel_dir), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -461,7 +461,7 @@ fn build_module_name_normalization() -> Result<()> {
     uv_snapshot!(context
         .build_backend()
         .arg("build-wheel")
-        .arg(&wheel_dir), @r"
+        .arg(&wheel_dir), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -479,7 +479,7 @@ fn build_module_name_normalization() -> Result<()> {
     uv_snapshot!(context
         .build_backend()
         .arg("build-wheel")
-        .arg(&wheel_dir), @r"
+        .arg(&wheel_dir), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -499,7 +499,7 @@ fn build_module_name_normalization() -> Result<()> {
 
     uv_snapshot!(context.python_command()
         .arg("-c")
-        .arg("import Django_plugin"), @r"
+        .arg("import Django_plugin"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -520,7 +520,7 @@ fn build_module_name_normalization() -> Result<()> {
         uv_snapshot!(context
             .build_backend()
             .arg("build-wheel")
-            .arg(&wheel_dir), @r"
+            .arg(&wheel_dir), @"
         success: true
         exit_code: 0
         ----- stdout -----
@@ -564,14 +564,14 @@ fn build_sdist_with_long_path() -> Result<()> {
     uv_snapshot!(context
         .build_backend()
         .arg("build-sdist")
-        .arg(temp_dir.path()), @r###"
+        .arg(temp_dir.path()), @"
     success: true
     exit_code: 0
     ----- stdout -----
     foo-1.0.0.tar.gz
 
     ----- stderr -----
-    "###);
+    ");
 
     Ok(())
 }
@@ -597,7 +597,7 @@ fn sdist_error_without_module() -> Result<()> {
     uv_snapshot!(context
         .build_backend()
         .arg("build-sdist")
-        .arg(temp_dir.path()), @r"
+        .arg(temp_dir.path()), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -611,7 +611,7 @@ fn sdist_error_without_module() -> Result<()> {
     uv_snapshot!(context
         .build_backend()
         .arg("build-sdist")
-        .arg(temp_dir.path()), @r"
+        .arg(temp_dir.path()), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -691,7 +691,7 @@ fn complex_namespace_packages() -> Result<()> {
             .arg("--offline")
             .arg("--find-links")
             .arg(dist.path()),
-        @r"
+        @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -708,7 +708,7 @@ fn complex_namespace_packages() -> Result<()> {
     uv_snapshot!(context.python_command()
         .arg("-c")
         .arg("from complex_project.part_b import two; print(two())"),
-        @r"
+        @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -728,7 +728,7 @@ fn complex_namespace_packages() -> Result<()> {
             .arg("-e")
             .arg("complex-project-part_b")
             .arg("--offline"),
-        @r"
+        @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -748,7 +748,7 @@ fn complex_namespace_packages() -> Result<()> {
     uv_snapshot!(context.python_command()
         .arg("-c")
         .arg("from complex_project.part_b import two; print(two())"),
-        @r"
+        @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -792,7 +792,7 @@ fn license_glob_without_matches_errors() -> Result<()> {
         .build_backend()
         .arg("build-wheel")
         .arg(context.temp_dir.path())
-        .current_dir(project.path()), @r"
+        .current_dir(project.path()), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -835,7 +835,7 @@ fn license_file_must_be_utf8() -> Result<()> {
         .build_backend()
         .arg("build-wheel")
         .arg(context.temp_dir.path())
-        .current_dir(project.path()), @r"
+        .current_dir(project.path()), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -885,7 +885,7 @@ fn symlinked_file() -> Result<()> {
         .build_backend()
         .arg("build-sdist")
         .arg(context.temp_dir.path())
-        .current_dir(project.path()), @r"
+        .current_dir(project.path()), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -898,7 +898,7 @@ fn symlinked_file() -> Result<()> {
         .build_backend()
         .arg("build-wheel")
         .arg(context.temp_dir.path())
-        .current_dir(project.path()), @r"
+        .current_dir(project.path()), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -907,7 +907,7 @@ fn symlinked_file() -> Result<()> {
     ----- stderr -----
     ");
 
-    uv_snapshot!(context.filters(), context.pip_install().arg("project-1.0.0-py3-none-any.whl"), @r"
+    uv_snapshot!(context.filters(), context.pip_install().arg("project-1.0.0-py3-none-any.whl"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -961,7 +961,7 @@ fn invalid_build_backend_settings_are_ignored() -> Result<()> {
 
     // Since we are not building, this must pass without complaining about the error in
     // `tool.uv.build-backend`.
-    uv_snapshot!(context.filters(), context.lock(), @r"
+    uv_snapshot!(context.filters(), context.lock(), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -996,7 +996,7 @@ fn error_on_relative_module_root_outside_project_root() -> Result<()> {
 
     context.temp_dir.child("__init__.py").touch()?;
 
-    uv_snapshot!(context.filters(), context.build(), @r"
+    uv_snapshot!(context.filters(), context.build(), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -1007,7 +1007,7 @@ fn error_on_relative_module_root_outside_project_root() -> Result<()> {
       ╰─▶ Module root must be inside the project: ..
     ");
 
-    uv_snapshot!(context.filters(), context.build().arg("--wheel"), @r"
+    uv_snapshot!(context.filters(), context.build().arg("--wheel"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -1051,7 +1051,7 @@ fn error_on_relative_data_dir_outside_project_root() -> Result<()> {
 
     context.temp_dir.child("headers").create_dir_all()?;
 
-    uv_snapshot!(context.filters(), context.build().arg("project"), @r"
+    uv_snapshot!(context.filters(), context.build().arg("project"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -1062,7 +1062,7 @@ fn error_on_relative_data_dir_outside_project_root() -> Result<()> {
       ╰─▶ The path for the data directory headers must be inside the project: ../header
     ");
 
-    uv_snapshot!(context.filters(), context.build().arg("project").arg("--wheel"), @r"
+    uv_snapshot!(context.filters(), context.build().arg("project").arg("--wheel"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -1095,7 +1095,7 @@ fn venv_in_source_tree() {
         .assert()
         .success();
 
-    uv_snapshot!(context.filters(), context.build(), @r"
+    uv_snapshot!(context.filters(), context.build(), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -1106,7 +1106,7 @@ fn venv_in_source_tree() {
       ╰─▶ Virtual environments must not be added to source distributions or wheels, remove the directory or exclude it from the build: src/foo/.venv
     ");
 
-    uv_snapshot!(context.filters(), context.build().arg("--wheel"), @r"
+    uv_snapshot!(context.filters(), context.build().arg("--wheel"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -1155,7 +1155,7 @@ fn warn_on_redundant_module_names() -> Result<()> {
     bar_module.child("__init__.py").touch()?;
 
     // Warnings should be printed when invoking `uv build`
-    uv_snapshot!(context.filters(), context.build(), @r"
+    uv_snapshot!(context.filters(), context.build(), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -1171,7 +1171,7 @@ fn warn_on_redundant_module_names() -> Result<()> {
     // But warnings shouldn't be printed in cases when the user might not
     // control the thing being built. Sources being enabled is a workable proxy
     // for this.
-    uv_snapshot!(context.filters(), context.build().arg("--no-sources"), @r"
+    uv_snapshot!(context.filters(), context.build().arg("--no-sources"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -1204,7 +1204,7 @@ fn invalid_pyproject_toml() -> Result<()> {
         build-backend = "uv_build"
     "#})?;
 
-    uv_snapshot!(context.filters(), context.build().arg("child"), @r"
+    uv_snapshot!(context.filters(), context.build().arg("child"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -1222,3 +1222,226 @@ fn invalid_pyproject_toml() -> Result<()> {
 
     Ok(())
 }
+
+#[cfg(feature = "pypi")]
+#[test]
+fn build_with_all_metadata() -> Result<()> {
+    let context = TestContext::new("3.12");
+    let temp_dir = TempDir::new()?;
+
+    context
+        .temp_dir
+        .child("pyproject.toml")
+        .write_str(indoc! {r#"
+        [project]
+        name = "foo"
+        version = "1.0.0"
+        description = "A Python package with all metadata fields"
+        readme = "Readme.md"
+        requires-python = ">=3.12"
+        license = "MIT OR Apache-2.0"
+        license-files = ["License*"]
+        authors = [
+            {name = "Jane Doe", email = "jane@example.com"},
+            {name = "John Doe"},
+            {email = "info@example.com"},
+        ]
+        maintainers = [
+            {name = "ferris", email = "ferris@example.com"},
+        ]
+        keywords = ["example", "test", "metadata"]
+        classifiers = [
+            "Development Status :: 4 - Beta",
+            "Programming Language :: Python :: 3",
+            "Programming Language :: Python :: 3.12",
+        ]
+        dependencies = [
+            "anyio>=4,<5",
+        ]
+
+        [project.optional-dependencies]
+        dev = ["pytest>=7.0"]
+
+        [project.urls]
+        Homepage = "https://octocat.github.io/spoon-knife"
+        Repository = "https://github.com/octocat/Spoon-Knife"
+        Changelog = "https://github.com/octocat/Spoon-Knife/blob/main/CHANGELOG.md"
+
+        [project.scripts]
+        foo-cli = "foo:main"
+
+        [project.gui-scripts]
+        foo-gui = "foo:gui_main"
+
+        [project.entry-points."foo.plugins"]
+        bar = "foo:bar_plugin"
+
+        [build-system]
+        requires = ["uv_build>=0.7,<10000"]
+        build-backend = "uv_build"
+    "#})?;
+    context
+        .temp_dir
+        .child("src/foo/__init__.py")
+        .write_str(indoc! {r#"
+        def main():
+            print("Hello from foo!")
+
+        def gui_main():
+            print("GUI main")
+
+        def bar_plugin():
+            pass
+    "#})?;
+    context
+        .temp_dir
+        .child("License.txt")
+        .write_str("MIT License")?;
+    context
+        .temp_dir
+        .child("Readme.md")
+        .write_str("Hello World!")?;
+
+    uv_snapshot!(context
+        .build_backend()
+        .arg("build-wheel")
+        .arg("--preview-features")
+        .arg("metadata-json")
+        .arg(temp_dir.path()), @"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    foo-1.0.0-py3-none-any.whl
+
+    ----- stderr -----
+    ");
+
+    context
+        .pip_install()
+        .arg(temp_dir.path().join("foo-1.0.0-py3-none-any.whl"))
+        .assert()
+        .success();
+
+    let metadata = fs_err::read_to_string(
+        context
+            .site_packages()
+            .join("foo-1.0.0.dist-info")
+            .join("METADATA"),
+    )?;
+    assert_snapshot!(metadata, @"
+    Metadata-Version: 2.4
+    Name: foo
+    Version: 1.0.0
+    Summary: A Python package with all metadata fields
+    Keywords: example,test,metadata
+    Author: Jane Doe, John Doe
+    Author-email: Jane Doe <jane@example.com>, info@example.com
+    License-Expression: MIT OR Apache-2.0
+    License-File: License.txt
+    Classifier: Development Status :: 4 - Beta
+    Classifier: Programming Language :: Python :: 3
+    Classifier: Programming Language :: Python :: 3.12
+    Requires-Dist: anyio>=4,<5
+    Requires-Dist: pytest>=7.0 ; extra == 'dev'
+    Maintainer: ferris
+    Maintainer-email: ferris <ferris@example.com>
+    Requires-Python: >=3.12
+    Project-URL: Homepage, https://octocat.github.io/spoon-knife
+    Project-URL: Repository, https://github.com/octocat/Spoon-Knife
+    Project-URL: Changelog, https://github.com/octocat/Spoon-Knife/blob/main/CHANGELOG.md
+    Provides-Extra: dev
+    Description-Content-Type: text/markdown
+
+    Hello World!
+    ");
+    let metadata_json = fs_err::read_to_string(
+        context
+            .site_packages()
+            .join("foo-1.0.0.dist-info")
+            .join("METADATA.json"),
+    )?;
+    let metadata_json: serde_json::Value = serde_json::from_str(&metadata_json)?;
+    assert_json_snapshot!(metadata_json, @r#"
+    {
+      "author": "Jane Doe, John Doe",
+      "author_email": "Jane Doe <jane@example.com>, info@example.com",
+      "classifiers": [
+        "Development Status :: 4 - Beta",
+        "Programming Language :: Python :: 3",
+        "Programming Language :: Python :: 3.12"
+      ],
+      "description": "Hello World!",
+      "description_content_type": "text/markdown",
+      "download_url": null,
+      "dynamic": [],
+      "home_page": null,
+      "keywords": [
+        "example",
+        "test",
+        "metadata"
+      ],
+      "license": null,
+      "license_expression": "MIT OR Apache-2.0",
+      "license_files": [
+        "License.txt"
+      ],
+      "maintainer": "ferris",
+      "maintainer_email": "ferris <ferris@example.com>",
+      "metadata_version": "2.4",
+      "name": "foo",
+      "obsoletes_dist": [],
+      "platforms": [],
+      "project_urls": {
+        "Changelog": "https://github.com/octocat/Spoon-Knife/blob/main/CHANGELOG.md",
+        "Homepage": "https://octocat.github.io/spoon-knife",
+        "Repository": "https://github.com/octocat/Spoon-Knife"
+      },
+      "provides_dist": [],
+      "provides_extra": [
+        "dev"
+      ],
+      "requires_dist": [
+        "anyio>=4,<5",
+        "pytest>=7.0 ; extra == 'dev'"
+      ],
+      "requires_external": [],
+      "requires_python": ">=3.12",
+      "summary": "A Python package with all metadata fields",
+      "supported_platforms": [],
+      "version": "1.0.0"
+    }
+    "#);
+    let wheel = fs_err::read_to_string(
+        context
+            .site_packages()
+            .join("foo-1.0.0.dist-info")
+            .join("WHEEL"),
+    )?;
+    let wheel = wheel.replace(uv_version::version(), "[VERSION]");
+    assert_snapshot!(wheel, @"
+    Wheel-Version: 1.0
+    Generator: uv [VERSION]
+    Root-Is-Purelib: true
+    Tag: py3-none-any
+    ");
+    let wheel_json = fs_err::read_to_string(
+        context
+            .site_packages()
+            .join("foo-1.0.0.dist-info")
+            .join("WHEEL.json"),
+    )?;
+    let wheel_json = wheel_json.replace(uv_version::version(), "[VERSION]");
+    let wheel_json: serde_json::Value = serde_json::from_str(&wheel_json)?;
+    assert_json_snapshot!(wheel_json, @r#"
+    {
+      "generator": "uv [VERSION]",
+      "root-is-purelib": true,
+      "tags": [
+        "py3-none-any"
+      ],
+      "wheel-version": "1.0"
+    }
+    "#);
+
+    Ok(())
+}
