@@ -83,7 +83,7 @@ async fn malo_accept_zip64_eocd() {
 #[tokio::test]
 async fn malo_iffy_8bitcomment() {
     let result = unzip("https://pub-c6f28d316acd406eae43501e51ad30fa.r2.dev/0723f54ceb33a4fdc7f2eddc19635cd704d61c84/iffy/8bitcomment.zip").await;
-    insta::assert_debug_snapshot!(result, @r"
+    insta::assert_debug_snapshot!(result, @"
     Err(
         ZipInZip,
     )
@@ -93,7 +93,7 @@ async fn malo_iffy_8bitcomment() {
 #[tokio::test]
 async fn malo_iffy_extra3byte() {
     let result = unzip("https://pub-c6f28d316acd406eae43501e51ad30fa.r2.dev/0723f54ceb33a4fdc7f2eddc19635cd704d61c84/iffy/extra3byte.zip").await;
-    insta::assert_debug_snapshot!(result, @r"
+    insta::assert_debug_snapshot!(result, @"
     Ok(
         (),
     )
@@ -103,7 +103,7 @@ async fn malo_iffy_extra3byte() {
 #[tokio::test]
 async fn malo_iffy_non_ascii_original_name() {
     let result = unzip("https://pub-c6f28d316acd406eae43501e51ad30fa.r2.dev/0723f54ceb33a4fdc7f2eddc19635cd704d61c84/iffy/non_ascii_original_name.zip").await;
-    insta::assert_debug_snapshot!(result, @r"
+    insta::assert_debug_snapshot!(result, @"
     Err(
         LocalHeaderNotUtf8 {
             offset: 0,
@@ -115,7 +115,7 @@ async fn malo_iffy_non_ascii_original_name() {
 #[tokio::test]
 async fn malo_iffy_nosubdir() {
     let result = unzip("https://pub-c6f28d316acd406eae43501e51ad30fa.r2.dev/0723f54ceb33a4fdc7f2eddc19635cd704d61c84/iffy/nosubdir.zip").await;
-    insta::assert_debug_snapshot!(result, @r"
+    insta::assert_debug_snapshot!(result, @"
     Ok(
         (),
     )
@@ -125,7 +125,7 @@ async fn malo_iffy_nosubdir() {
 #[tokio::test]
 async fn malo_iffy_prefix() {
     let result = unzip("https://pub-c6f28d316acd406eae43501e51ad30fa.r2.dev/0723f54ceb33a4fdc7f2eddc19635cd704d61c84/iffy/prefix.zip").await;
-    insta::assert_debug_snapshot!(result, @r"
+    insta::assert_debug_snapshot!(result, @"
     Err(
         AsyncZip(
             UnexpectedHeaderError(
@@ -140,7 +140,7 @@ async fn malo_iffy_prefix() {
 #[tokio::test]
 async fn malo_iffy_suffix_not_comment() {
     let result = unzip("https://pub-c6f28d316acd406eae43501e51ad30fa.r2.dev/0723f54ceb33a4fdc7f2eddc19635cd704d61c84/iffy/suffix_not_comment.zip").await;
-    insta::assert_debug_snapshot!(result, @r"
+    insta::assert_debug_snapshot!(result, @"
     Err(
         TrailingContents,
     )
@@ -150,7 +150,7 @@ async fn malo_iffy_suffix_not_comment() {
 #[tokio::test]
 async fn malo_iffy_zip64_eocd_extensible_data() {
     let result = unzip("https://pub-c6f28d316acd406eae43501e51ad30fa.r2.dev/0723f54ceb33a4fdc7f2eddc19635cd704d61c84/iffy/zip64_eocd_extensible_data.zip").await;
-    insta::assert_debug_snapshot!(result, @r"
+    insta::assert_debug_snapshot!(result, @"
     Err(
         ExtensibleData,
     )
@@ -160,7 +160,7 @@ async fn malo_iffy_zip64_eocd_extensible_data() {
 #[tokio::test]
 async fn malo_iffy_zip64_extra_too_long() {
     let result = unzip("https://pub-c6f28d316acd406eae43501e51ad30fa.r2.dev/0723f54ceb33a4fdc7f2eddc19635cd704d61c84/iffy/zip64_extra_too_long.zip").await;
-    insta::assert_debug_snapshot!(result, @r"
+    insta::assert_debug_snapshot!(result, @"
     Err(
         AsyncZip(
             Zip64ExtendedInformationFieldTooLong {
@@ -301,7 +301,7 @@ async fn malo_reject_dupe_eocd() {
 #[tokio::test]
 async fn malo_reject_shortextra() {
     let result = unzip("https://pub-c6f28d316acd406eae43501e51ad30fa.r2.dev/0723f54ceb33a4fdc7f2eddc19635cd704d61c84/reject/shortextra.zip").await.unwrap_err();
-    insta::assert_debug_snapshot!(result, @r"
+    insta::assert_debug_snapshot!(result, @"
     AsyncZip(
         InvalidExtraFieldHeader(
             9,
@@ -337,7 +337,7 @@ async fn malo_reject_zip64_extra_usize() {
 #[tokio::test]
 async fn malo_malicious_second_unicode_extra() {
     let result = unzip("https://pub-c6f28d316acd406eae43501e51ad30fa.r2.dev/0723f54ceb33a4fdc7f2eddc19635cd704d61c84/malicious/second_unicode_extra.zip").await.unwrap_err();
-    insta::assert_debug_snapshot!(result, @r"
+    insta::assert_debug_snapshot!(result, @"
     AsyncZip(
         DuplicateExtraFieldHeader(
             28789,
@@ -349,7 +349,7 @@ async fn malo_malicious_second_unicode_extra() {
 #[tokio::test]
 async fn malo_malicious_short_usize_zip64() {
     let result = unzip("https://pub-c6f28d316acd406eae43501e51ad30fa.r2.dev/0723f54ceb33a4fdc7f2eddc19635cd704d61c84/malicious/short_usize_zip64.zip").await.unwrap_err();
-    insta::assert_debug_snapshot!(result, @r"
+    insta::assert_debug_snapshot!(result, @"
     AsyncZip(
         Zip64ExtendedInformationFieldTooLong {
             expected: 16,
@@ -380,7 +380,7 @@ async fn malo_malicious_zip64_eocd_confusion() {
 #[tokio::test]
 async fn malo_malicious_unicode_extra_chain() {
     let result = unzip("https://pub-c6f28d316acd406eae43501e51ad30fa.r2.dev/0723f54ceb33a4fdc7f2eddc19635cd704d61c84/malicious/unicode_extra_chain.zip").await.unwrap_err();
-    insta::assert_debug_snapshot!(result, @r"
+    insta::assert_debug_snapshot!(result, @"
     AsyncZip(
         DuplicateExtraFieldHeader(
             28789,
